@@ -12,9 +12,9 @@ from picklefield.fields import PickledObjectField
 
 from celery import schedules
 from celery import states
-from celery.app import default_app
 from celery.utils.timeutils import timedelta_seconds
 
+from djcelery.app import app as celery
 from djcelery.managers import TaskManager, TaskSetManager, ExtendedManager
 from djcelery.managers import TaskStateManager, PeriodicTaskManager
 
@@ -310,16 +310,8 @@ class TaskState(models.Model):
 
 
 if (django.VERSION[0], django.VERSION[1]) >= (1, 1):
-    # keep models away from syncdb/reset if django database
+    # Keep models away from syncdb/reset if Django database
     # backend is not being used.
-
-    # We can be sure the django database backend (or its subclass) is
-    # not being used only if the backend is one of standard
-    # celery's backends.
-
-    from celery.backends import BACKEND_ALIASES
-    known_names = BACKEND_ALIASES.keys() + BACKEND_ALIASES.values()
-
-    if default_app.conf.CELERY_RESULT_BACKEND in known_names:
+    if not getattr(celery.backend, "create_django_tables", False):
         TaskMeta._meta.managed = False
         TaskSetMeta._meta.managed = False
